@@ -1,48 +1,33 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "context.h"
 #include "server.h"
 
-#include <QAbstractEventDispatcher>
 #include "debug.h"
+#include <QAbstractEventDispatcher>
+#include <QDBusConnection>
+#include <QDBusServiceWatcher>
 #include <QMutexLocker>
 #include <QTimer>
-#include <QDBusServiceWatcher>
-#include <QDBusConnection>
 
 #include "card.h"
 #include "client.h"
+#include "module.h"
 #include "sink.h"
 #include "sinkinput.h"
 #include "source.h"
 #include "sourceoutput.h"
 #include "streamrestore.h"
-#include "module.h"
 
 #include <KLocalizedString>
 
 namespace QPulseAudio
 {
-
-Context* Context::s_context = nullptr;
+Context *Context::s_context = nullptr;
 
 const qint64 Context::NormalVolume = PA_VOLUME_NORM;
 const qint64 Context::MinimalVolume = 0;
@@ -67,8 +52,9 @@ static bool isGoodState(int eol)
 
 static void sink_cb(pa_context *context, const pa_sink_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     Q_ASSERT(context);
     Q_ASSERT(data);
     ((Context *)data)->sinkCallback(info);
@@ -76,8 +62,9 @@ static void sink_cb(pa_context *context, const pa_sink_info *info, int eol, void
 
 static void sink_input_callback(pa_context *context, const pa_sink_input_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     // pulsesink probe is used by gst-pulse only to query sink formats (not for playback)
     if (qstrcmp(info->name, "pulsesink probe") == 0) {
         return;
@@ -95,11 +82,13 @@ static void sink_input_callback(pa_context *context, const pa_sink_input_info *i
 
 static void source_cb(pa_context *context, const pa_source_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     // FIXME: This forces excluding monitors
-    if (info->monitor_of_sink != PA_INVALID_INDEX)
+    if (info->monitor_of_sink != PA_INVALID_INDEX) {
         return;
+    }
     Q_ASSERT(context);
     Q_ASSERT(data);
     ((Context *)data)->sourceCallback(info);
@@ -107,15 +96,17 @@ static void source_cb(pa_context *context, const pa_source_info *info, int eol,
 
 static void source_output_cb(pa_context *context, const pa_source_output_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     // FIXME: This forces excluding these apps
     if (const char *app = pa_proplist_gets(info->proplist, PA_PROP_APPLICATION_ID)) {
-        if (strcmp(app, "org.PulseAudio.pavucontrol") == 0
-                || strcmp(app, "org.gnome.VolumeControl") == 0
-                || strcmp(app, "org.kde.kmixd") == 0
-                || strcmp(app, "org.kde.plasma-pa") == 0)
+        if (strcmp(app, "org.PulseAudio.pavucontrol") == 0 //
+            || strcmp(app, "org.gnome.VolumeControl") == 0 //
+            || strcmp(app, "org.kde.kmixd") == 0 //
+            || strcmp(app, "org.kde.plasma-pa") == 0) {
             return;
+        }
     }
     Q_ASSERT(context);
     Q_ASSERT(data);
@@ -124,8 +115,9 @@ static void source_output_cb(pa_context *context, const pa_source_output_info *i
 
 static void client_cb(pa_context *context, const pa_client_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     Q_ASSERT(context);
     Q_ASSERT(data);
     ((Context *)data)->clientCallback(info);
@@ -133,8 +125,9 @@ static void client_cb(pa_context *context, const pa_client_info *info, int eol,
 
 static void card_cb(pa_context *context, const pa_card_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     Q_ASSERT(context);
     Q_ASSERT(data);
     ((Context *)data)->cardCallback(info);
@@ -142,8 +135,9 @@ static void card_cb(pa_context *context, const pa_card_info *info, int eol, void
 
 static void module_info_list_cb(pa_context *context, const pa_module_info *info, int eol, void *data)
 {
-    if (!isGoodState(eol))
+    if (!isGoodState(eol)) {
         return;
+    }
     Q_ASSERT(context);
     Q_ASSERT(data);
     ((Context *)data)->moduleCallback(info);
@@ -236,7 +230,7 @@ Context::Context(QObject *parent)
     , m_mainloop(nullptr)
     , m_references(0)
 {
-    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(QStringLiteral("org.pulseaudio.Server"),
+    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(QStringLiteral("org.pulseaudio.Server"), //
                                                            QDBusConnection::sessionBus(),
                                                            QDBusServiceWatcher::WatchForRegistration,
                                                            this);
@@ -362,14 +356,12 @@ void Context::subscribeCallback(pa_context *context, pa_subscription_event_type_
         }
         break;
 
-
     case PA_SUBSCRIPTION_EVENT_SERVER:
         if (!PAOperation(pa_context_get_server_info(context, server_cb, this))) {
             qCWarning(PLASMAPA) << "pa_context_get_server_info() failed";
             return;
         }
         break;
-
     }
 }
 
@@ -384,15 +376,13 @@ void Context::contextStateCallback(pa_context *c)
         if (m_context == c) {
             pa_context_set_subscribe_callback(c, subscribe_cb, this);
 
-            if (!PAOperation(pa_context_subscribe(c, (pa_subscription_mask_t)
-                                           (PA_SUBSCRIPTION_MASK_SINK|
-                                            PA_SUBSCRIPTION_MASK_SOURCE|
-                                            PA_SUBSCRIPTION_MASK_CLIENT|
-                                            PA_SUBSCRIPTION_MASK_SINK_INPUT|
-                                            PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT|
-                                            PA_SUBSCRIPTION_MASK_CARD|
-                                            PA_SUBSCRIPTION_MASK_MODULE|
-                                            PA_SUBSCRIPTION_MASK_SERVER), nullptr, nullptr))) {
+            if (!PAOperation(
+                    pa_context_subscribe(c,
+                                         (pa_subscription_mask_t)(PA_SUBSCRIPTION_MASK_SINK | PA_SUBSCRIPTION_MASK_SOURCE | PA_SUBSCRIPTION_MASK_CLIENT
+                                                                  | PA_SUBSCRIPTION_MASK_SINK_INPUT | PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT
+                                                                  | PA_SUBSCRIPTION_MASK_CARD | PA_SUBSCRIPTION_MASK_MODULE | PA_SUBSCRIPTION_MASK_SERVER),
+                                         nullptr,
+                                         nullptr))) {
                 qCWarning(PLASMAPA) << "pa_context_subscribe() failed";
                 return;
             }
@@ -502,8 +492,7 @@ void Context::streamRestoreCallback(const pa_ext_stream_restore_info *info)
 
     if (!obj) {
         QVariantMap props;
-        props.insert(QStringLiteral("application.icon_name"),
-                     QStringLiteral("preferences-desktop-notification"));
+        props.insert(QStringLiteral("application.icon_name"), QStringLiteral("preferences-desktop-notification"));
         obj = new StreamRestore(eventRoleIndex, props, this);
         obj->update(info);
         m_streamRestores.insert(obj);
@@ -523,10 +512,7 @@ void Context::setCardProfile(quint32 index, const QString &profile)
         return;
     }
     qCDebug(PLASMAPA) << index << profile;
-    if (!PAOperation(pa_context_set_card_profile_by_index(m_context,
-                                                          index,
-                                                          profile.toUtf8().constData(),
-                                                          nullptr, nullptr))) {
+    if (!PAOperation(pa_context_set_card_profile_by_index(m_context, index, profile.toUtf8().constData(), nullptr, nullptr))) {
         qCWarning(PLASMAPA) << "pa_context_set_card_profile_by_index failed";
         return;
     }
@@ -538,18 +524,13 @@ void Context::setDefaultSink(const QString &name)
         return;
     }
     const QByteArray nameData = name.toUtf8();
-    if (!PAOperation(pa_context_set_default_sink(m_context,
-                                                 nameData.constData(),
-                                                 nullptr,
-                                                 nullptr))) {
+    if (!PAOperation(pa_context_set_default_sink(m_context, nameData.constData(), nullptr, nullptr))) {
         qCWarning(PLASMAPA) << "pa_context_set_default_sink failed";
     }
 
     // Change device for all entries in stream-restore database
     m_newDefaultSink = name;
-    if (!PAOperation(pa_ext_stream_restore_read(m_context,
-                                                ext_stream_restore_change_sink_cb,
-                                                this))) {
+    if (!PAOperation(pa_ext_stream_restore_read(m_context, ext_stream_restore_change_sink_cb, this))) {
         qCWarning(PLASMAPA) << "pa_ext_stream_restore_read failed";
     }
 }
@@ -560,18 +541,13 @@ void Context::setDefaultSource(const QString &name)
         return;
     }
     const QByteArray nameData = name.toUtf8();
-    if (!PAOperation(pa_context_set_default_source(m_context,
-                                                 nameData.constData(),
-                                                 nullptr,
-                                                 nullptr))) {
+    if (!PAOperation(pa_context_set_default_source(m_context, nameData.constData(), nullptr, nullptr))) {
         qCWarning(PLASMAPA) << "pa_context_set_default_source failed";
     }
 
     // Change device for all entries in stream-restore database
     m_newDefaultSource = name;
-    if (!PAOperation(pa_ext_stream_restore_read(m_context,
-                                                ext_stream_restore_change_source_cb,
-                                                this))) {
+    if (!PAOperation(pa_ext_stream_restore_read(m_context, ext_stream_restore_change_source_cb, this))) {
         qCWarning(PLASMAPA) << "pa_ext_stream_restore_read failed";
     }
 }
@@ -581,13 +557,7 @@ void Context::streamRestoreWrite(const pa_ext_stream_restore_info *info)
     if (!m_context) {
         return;
     }
-    if (!PAOperation(pa_ext_stream_restore_write(m_context,
-                                                 PA_UPDATE_REPLACE,
-                                                 info,
-                                                 1,
-                                                 true,
-                                                 nullptr,
-                                                 nullptr))) {
+    if (!PAOperation(pa_ext_stream_restore_write(m_context, PA_UPDATE_REPLACE, info, 1, true, nullptr, nullptr))) {
         qCWarning(PLASMAPA) << "pa_ext_stream_restore_write failed";
     }
 }
@@ -599,13 +569,13 @@ void Context::connectToDaemon()
     }
 
     // We require a glib event loop
-    if (!QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("EventDispatcherGlib") &&
-        !QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("GlibEventDispatcher")) {
+    if (!QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("EventDispatcherGlib")
+        && !QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("GlibEventDispatcher")) {
         qCWarning(PLASMAPA) << "Disabling PulseAudio integration for lack of GLib event loop";
         return;
     }
 
-    qCDebug(PLASMAPA) <<  "Attempting connection to PulseAudio sound daemon";
+    qCDebug(PLASMAPA) << "Attempting connection to PulseAudio sound daemon";
     if (!m_mainloop) {
         m_mainloop = pa_glib_mainloop_new(nullptr);
         Q_ASSERT(m_mainloop);
